# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/environment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from dialogflow_v2beta1.proto import (
    audio_config_pb2 as google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_audio__config__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/environment.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\020EnvironmentProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n7google/cloud/dialogflow_v2beta1/proto/environment.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x38google/cloud/dialogflow_v2beta1/proto/audio_config.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xc8\x03\n\x0b\x45nvironment\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x1a\n\ragent_version\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x46\n\x05state\x18\x04 \x01(\x0e\x32\x32.google.cloud.dialogflow.v2beta1.Environment.StateB\x03\xe0\x41\x03\x12\x34\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07STOPPED\x10\x01\x12\x0b\n\x07LOADING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03:\xaa\x01\xea\x41\xa6\x01\n%dialogflow.googleapis.com/Environment\x12\x33projects/{project}/agent/environments/{environment}\x12Hprojects/{project}/locations/{location}/agent/environments/{environment}"\x89\x01\n\x17ListEnvironmentsRequest\x12=\n\x06parent\x18\x01 \x01(\tB-\xe0\x41\x02\xfa\x41\'\x12%dialogflow.googleapis.com/Environment\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01"w\n\x18ListEnvironmentsResponse\x12\x42\n\x0c\x65nvironments\x18\x01 \x03(\x0b\x32,.google.cloud.dialogflow.v2beta1.Environment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x93\x03\n\x0c\x45nvironments\x12\x88\x02\n\x10ListEnvironments\x12\x38.google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest\x1a\x39.google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse"\x7f\x82\xd3\xe4\x93\x02p\x12//v2beta1/{parent=projects/*/agent}/environmentsZ=\x12;/v2beta1/{parent=projects/*/locations/*/agent}/environments\xda\x41\x06parent\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xae\x01\n#com.google.cloud.dialogflow.v2beta1B\x10\x45nvironmentProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_dialogflow__v2beta1_dot_proto_dot_audio__config__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_ENVIRONMENT_STATE = _descriptor.EnumDescriptor(
    name="State",
    full_name="google.cloud.dialogflow.v2beta1.Environment.State",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="STATE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="STOPPED",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LOADING",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RUNNING",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=576,
    serialized_end=645,
)
_sym_db.RegisterEnumDescriptor(_ENVIRONMENT_STATE)


_ENVIRONMENT = _descriptor.Descriptor(
    name="Environment",
    full_name="google.cloud.dialogflow.v2beta1.Environment",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.Environment.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.dialogflow.v2beta1.Environment.description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="agent_version",
            full_name="google.cloud.dialogflow.v2beta1.Environment.agent_version",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="state",
            full_name="google.cloud.dialogflow.v2beta1.Environment.state",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.dialogflow.v2beta1.Environment.update_time",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_ENVIRONMENT_STATE],
    serialized_options=b"\352A\246\001\n%dialogflow.googleapis.com/Environment\0223projects/{project}/agent/environments/{environment}\022Hprojects/{project}/locations/{location}/agent/environments/{environment}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=362,
    serialized_end=818,
)


_LISTENVIRONMENTSREQUEST = _descriptor.Descriptor(
    name="ListEnvironmentsRequest",
    full_name="google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A'\022%dialogflow.googleapis.com/Environment",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=821,
    serialized_end=958,
)


_LISTENVIRONMENTSRESPONSE = _descriptor.Descriptor(
    name="ListEnvironmentsResponse",
    full_name="google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="environments",
            full_name="google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse.environments",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=960,
    serialized_end=1079,
)

_ENVIRONMENT.fields_by_name["state"].enum_type = _ENVIRONMENT_STATE
_ENVIRONMENT.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ENVIRONMENT_STATE.containing_type = _ENVIRONMENT
_LISTENVIRONMENTSRESPONSE.fields_by_name["environments"].message_type = _ENVIRONMENT
DESCRIPTOR.message_types_by_name["Environment"] = _ENVIRONMENT
DESCRIPTOR.message_types_by_name["ListEnvironmentsRequest"] = _LISTENVIRONMENTSREQUEST
DESCRIPTOR.message_types_by_name["ListEnvironmentsResponse"] = _LISTENVIRONMENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Environment = _reflection.GeneratedProtocolMessageType(
    "Environment",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENVIRONMENT,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.environment_pb2",
        "__doc__": """You can create multiple versions of your agent and publish them to
  separate environments.  When you edit an agent, you are editing the
  draft agent. At any point, you can save the draft agent as an agent
  version, which is an immutable snapshot of your agent.  When you save
  the draft agent, it is published to the default environment. When you
  create agent versions, you can publish them to custom environments.
  You can create a variety of custom environments for:  -  testing -
  development -  production -  etc.  For more information, see the
  `versions and environments guide
  <https://cloud.google.com/dialogflow/docs/agents-versions>`__.
  
  Attributes:
      name:
          Output only. The unique identifier of this agent environment.
          Format: - ``projects/<Project Number /
          ID>/agent/environments/<Environment ID>`` -
          ``projects/<Project Number / ID>/locations/<Location
          ID>/agent/environments/<Environment ID>``
      description:
          Optional. The developer-provided description for this
          environment. The maximum length is 500 characters. If
          exceeded, the request is rejected.
      agent_version:
          Optional. The agent version loaded into this environment.
          Format: ``projects/<Project ID>/agent/versions/<Version ID>``.
      state:
          Output only. The state of this environment. This field is
          read-only, i.e., it cannot be set by create and update
          methods.
      update_time:
          Output only. The last update time of this environment. This
          field is read-only, i.e., it cannot be set by create and
          update methods.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Environment)
    },
)
_sym_db.RegisterMessage(Environment)

ListEnvironmentsRequest = _reflection.GeneratedProtocolMessageType(
    "ListEnvironmentsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTENVIRONMENTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.environment_pb2",
        "__doc__": """The request message for [Environments.ListEnvironments][google.cloud.d
  ialogflow.v2beta1.Environments.ListEnvironments].
  
  Attributes:
      parent:
          Required. The agent to list all environments from. Format: -
          ``projects/<Project Number / ID>/agent`` -
          \`projects//locations//agent
      page_size:
          Optional. The maximum number of items to return in a single
          page. By default 100 and at most 1000.
      page_token:
          Optional. The next_page_token value returned from a previous
          list request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListEnvironmentsRequest)
    },
)
_sym_db.RegisterMessage(ListEnvironmentsRequest)

ListEnvironmentsResponse = _reflection.GeneratedProtocolMessageType(
    "ListEnvironmentsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTENVIRONMENTSRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.environment_pb2",
        "__doc__": """The response message for [Environments.ListEnvironments][google.cloud.
  dialogflow.v2beta1.Environments.ListEnvironments].
  
  Attributes:
      environments:
          The list of agent environments. There will be a maximum number
          of items returned based on the page_size field in the request.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListEnvironmentsResponse)
    },
)
_sym_db.RegisterMessage(ListEnvironmentsResponse)


DESCRIPTOR._options = None
_ENVIRONMENT.fields_by_name["name"]._options = None
_ENVIRONMENT.fields_by_name["description"]._options = None
_ENVIRONMENT.fields_by_name["agent_version"]._options = None
_ENVIRONMENT.fields_by_name["state"]._options = None
_ENVIRONMENT.fields_by_name["update_time"]._options = None
_ENVIRONMENT._options = None
_LISTENVIRONMENTSREQUEST.fields_by_name["parent"]._options = None
_LISTENVIRONMENTSREQUEST.fields_by_name["page_size"]._options = None
_LISTENVIRONMENTSREQUEST.fields_by_name["page_token"]._options = None

_ENVIRONMENTS = _descriptor.ServiceDescriptor(
    name="Environments",
    full_name="google.cloud.dialogflow.v2beta1.Environments",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=1082,
    serialized_end=1485,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListEnvironments",
            full_name="google.cloud.dialogflow.v2beta1.Environments.ListEnvironments",
            index=0,
            containing_service=None,
            input_type=_LISTENVIRONMENTSREQUEST,
            output_type=_LISTENVIRONMENTSRESPONSE,
            serialized_options=b"\202\323\344\223\002p\022//v2beta1/{parent=projects/*/agent}/environmentsZ=\022;/v2beta1/{parent=projects/*/locations/*/agent}/environments\332A\006parent",
            create_key=_descriptor._internal_create_key,
        )
    ],
)
_sym_db.RegisterServiceDescriptor(_ENVIRONMENTS)

DESCRIPTOR.services_by_name["Environments"] = _ENVIRONMENTS

# @@protoc_insertion_point(module_scope)
