# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/context.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/context.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\014ContextProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n3google/cloud/dialogflow_v2beta1/proto/context.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto"\x83\x03\n\x07\x43ontext\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0elifespan_count\x18\x02 \x01(\x05\x12+\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct:\xa4\x02\xea\x41\xa0\x02\n!dialogflow.googleapis.com/Context\x12>projects/{project}/agent/sessions/{session}/contexts/{context}\x12\x66projects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}/contexts/{context}\x12Sprojects/{project}/locations/{location}/agent/sessions/{session}/contexts/{context}"w\n\x13ListContextsRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\x12!dialogflow.googleapis.com/Context\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"k\n\x14ListContextsResponse\x12:\n\x08\x63ontexts\x18\x01 \x03(\x0b\x32(.google.cloud.dialogflow.v2beta1.Context\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"L\n\x11GetContextRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!dialogflow.googleapis.com/Context"\x91\x01\n\x14\x43reateContextRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\x12!dialogflow.googleapis.com/Context\x12>\n\x07\x63ontext\x18\x02 \x01(\x0b\x32(.google.cloud.dialogflow.v2beta1.ContextB\x03\xe0\x41\x02"\x8c\x01\n\x14UpdateContextRequest\x12>\n\x07\x63ontext\x18\x01 \x01(\x0b\x32(.google.cloud.dialogflow.v2beta1.ContextB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01"O\n\x14\x44\x65leteContextRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!dialogflow.googleapis.com/Context"U\n\x18\x44\x65leteAllContextsRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\x12!dialogflow.googleapis.com/Context2\x9c\x16\n\x08\x43ontexts\x12\xba\x03\n\x0cListContexts\x12\x34.google.cloud.dialogflow.v2beta1.ListContextsRequest\x1a\x35.google.cloud.dialogflow.v2beta1.ListContextsResponse"\xbc\x02\x82\xd3\xe4\x93\x02\xac\x02\x12\x36/v2beta1/{parent=projects/*/agent/sessions/*}/contextsZO\x12M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contextsZD\x12\x42/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contextsZ[\x12Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts\xda\x41\x06parent\x12\xa7\x03\n\nGetContext\x12\x32.google.cloud.dialogflow.v2beta1.GetContextRequest\x1a(.google.cloud.dialogflow.v2beta1.Context"\xba\x02\x82\xd3\xe4\x93\x02\xac\x02\x12\x36/v2beta1/{name=projects/*/agent/sessions/*/contexts/*}ZO\x12M/v2beta1/{name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}ZD\x12\x42/v2beta1/{name=projects/*/locations/*/agent/sessions/*/contexts/*}Z[\x12Y/v2beta1/{name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}\xda\x41\x04name\x12\xdb\x03\n\rCreateContext\x12\x35.google.cloud.dialogflow.v2beta1.CreateContextRequest\x1a(.google.cloud.dialogflow.v2beta1.Context"\xe8\x02\x82\xd3\xe4\x93\x02\xd0\x02"6/v2beta1/{parent=projects/*/agent/sessions/*}/contexts:\x07\x63ontextZX"M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contexts:\x07\x63ontextZM"B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contexts:\x07\x63ontextZd"Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts:\x07\x63ontext\xda\x41\x0eparent,context\x12\x8a\x04\n\rUpdateContext\x12\x35.google.cloud.dialogflow.v2beta1.UpdateContextRequest\x1a(.google.cloud.dialogflow.v2beta1.Context"\x97\x03\x82\xd3\xe4\x93\x02\xf0\x02\x32>/v2beta1/{context.name=projects/*/agent/sessions/*/contexts/*}:\x07\x63ontextZ`2U/v2beta1/{context.name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}:\x07\x63ontextZU2J/v2beta1/{context.name=projects/*/locations/*/agent/sessions/*/contexts/*}:\x07\x63ontextZl2a/v2beta1/{context.name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}:\x07\x63ontext\xda\x41\x13\x63ontext,update_mask\xda\x41\x07\x63ontext\x12\x9b\x03\n\rDeleteContext\x12\x35.google.cloud.dialogflow.v2beta1.DeleteContextRequest\x1a\x16.google.protobuf.Empty"\xba\x02\x82\xd3\xe4\x93\x02\xac\x02*6/v2beta1/{name=projects/*/agent/sessions/*/contexts/*}ZO*M/v2beta1/{name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}ZD*B/v2beta1/{name=projects/*/locations/*/agent/sessions/*/contexts/*}Z[*Y/v2beta1/{name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}\xda\x41\x04name\x12\xa5\x03\n\x11\x44\x65leteAllContexts\x12\x39.google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest\x1a\x16.google.protobuf.Empty"\xbc\x02\x82\xd3\xe4\x93\x02\xac\x02*6/v2beta1/{parent=projects/*/agent/sessions/*}/contextsZO*M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contextsZD*B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contextsZ[*Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts\xda\x41\x06parent\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xaa\x01\n#com.google.cloud.dialogflow.v2beta1B\x0c\x43ontextProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
    ],
)


_CONTEXT = _descriptor.Descriptor(
    name="Context",
    full_name="google.cloud.dialogflow.v2beta1.Context",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.Context.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="lifespan_count",
            full_name="google.cloud.dialogflow.v2beta1.Context.lifespan_count",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="google.cloud.dialogflow.v2beta1.Context.parameters",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A\240\002\n!dialogflow.googleapis.com/Context\022>projects/{project}/agent/sessions/{session}/contexts/{context}\022fprojects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}/contexts/{context}\022Sprojects/{project}/locations/{location}/agent/sessions/{session}/contexts/{context}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=297,
    serialized_end=684,
)


_LISTCONTEXTSREQUEST = _descriptor.Descriptor(
    name="ListContextsRequest",
    full_name="google.cloud.dialogflow.v2beta1.ListContextsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\022!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=686,
    serialized_end=805,
)


_LISTCONTEXTSRESPONSE = _descriptor.Descriptor(
    name="ListContextsResponse",
    full_name="google.cloud.dialogflow.v2beta1.ListContextsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="contexts",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsResponse.contexts",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListContextsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=807,
    serialized_end=914,
)


_GETCONTEXTREQUEST = _descriptor.Descriptor(
    name="GetContextRequest",
    full_name="google.cloud.dialogflow.v2beta1.GetContextRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.GetContextRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\n!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=916,
    serialized_end=992,
)


_CREATECONTEXTREQUEST = _descriptor.Descriptor(
    name="CreateContextRequest",
    full_name="google.cloud.dialogflow.v2beta1.CreateContextRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.CreateContextRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\022!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="google.cloud.dialogflow.v2beta1.CreateContextRequest.context",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=995,
    serialized_end=1140,
)


_UPDATECONTEXTREQUEST = _descriptor.Descriptor(
    name="UpdateContextRequest",
    full_name="google.cloud.dialogflow.v2beta1.UpdateContextRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="context",
            full_name="google.cloud.dialogflow.v2beta1.UpdateContextRequest.context",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.UpdateContextRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1143,
    serialized_end=1283,
)


_DELETECONTEXTREQUEST = _descriptor.Descriptor(
    name="DeleteContextRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteContextRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.DeleteContextRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\n!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1285,
    serialized_end=1364,
)


_DELETEALLCONTEXTSREQUEST = _descriptor.Descriptor(
    name="DeleteAllContextsRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A#\022!dialogflow.googleapis.com/Context",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1366,
    serialized_end=1451,
)

_CONTEXT.fields_by_name[
    "parameters"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LISTCONTEXTSRESPONSE.fields_by_name["contexts"].message_type = _CONTEXT
_CREATECONTEXTREQUEST.fields_by_name["context"].message_type = _CONTEXT
_UPDATECONTEXTREQUEST.fields_by_name["context"].message_type = _CONTEXT
_UPDATECONTEXTREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name["Context"] = _CONTEXT
DESCRIPTOR.message_types_by_name["ListContextsRequest"] = _LISTCONTEXTSREQUEST
DESCRIPTOR.message_types_by_name["ListContextsResponse"] = _LISTCONTEXTSRESPONSE
DESCRIPTOR.message_types_by_name["GetContextRequest"] = _GETCONTEXTREQUEST
DESCRIPTOR.message_types_by_name["CreateContextRequest"] = _CREATECONTEXTREQUEST
DESCRIPTOR.message_types_by_name["UpdateContextRequest"] = _UPDATECONTEXTREQUEST
DESCRIPTOR.message_types_by_name["DeleteContextRequest"] = _DELETECONTEXTREQUEST
DESCRIPTOR.message_types_by_name["DeleteAllContextsRequest"] = _DELETEALLCONTEXTSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Context = _reflection.GeneratedProtocolMessageType(
    "Context",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONTEXT,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """Dialogflow contexts are similar to natural language context. If a
  person says to you “they are orange”, you need context in order to
  understand what “they” is referring to. Similarly, for Dialogflow to
  handle an end-user expression like that, it needs to be provided with
  context in order to correctly match an intent.  Using contexts, you
  can control the flow of a conversation. You can configure contexts for
  an intent by setting input and output contexts, which are identified
  by string names. When an intent is matched, any configured output
  contexts for that intent become active. While any contexts are active,
  Dialogflow is more likely to match intents that are configured with
  input contexts that correspond to the currently active contexts.  For
  more information about context, see the `Contexts guide
  <https://cloud.google.com/dialogflow/docs/contexts-overview>`__.
  
  Attributes:
      name:
          Required. The unique identifier of the context. Format:
          ``projects/<Project ID>/agent/sessions/<Session
          ID>/contexts/<Context ID>``, or ``projects/<Project
          ID>/agent/environments/<Environment ID>/users/<User
          ID>/sessions/<Session ID>/contexts/<Context ID>``.  The
          ``Context ID`` is always converted to lowercase, may only
          contain characters in a-zA-Z0-9_-% and may be at most 250
          bytes long.  If ``Environment ID`` is not specified, we assume
          default ‘draft’ environment. If ``User ID`` is not specified,
          we assume default ‘-’ user.  The following context names are
          reserved for internal use by Dialogflow. You should not use
          these contexts or create contexts with these names:  -
          ``__system_counters__`` -  ``*_id_dialog_context`` -
          ``*_dialog_params_size``
      lifespan_count:
          Optional. The number of conversational query requests after
          which the context expires. The default is ``0``. If set to
          ``0``, the context expires immediately. Contexts expire
          automatically after 20 minutes if there are no matching
          queries.
      parameters:
          Optional. The collection of parameters associated with this
          context.  Depending on your protocol or client library
          language, this is a map, associative array, symbol table,
          dictionary, or JSON object composed of a collection of
          (MapKey, MapValue) pairs:  -  MapKey type: string -  MapKey
          value: parameter name -  MapValue type:     -  If parameter’s
          entity type is a composite entity: map    -  Else: string or
          number, depending on parameter value type  -  MapValue value:
          -  If parameter’s entity type is a composite entity: map from
          composite entity property names to property values    -  Else:
          parameter value
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.Context)
    },
)
_sym_db.RegisterMessage(Context)

ListContextsRequest = _reflection.GeneratedProtocolMessageType(
    "ListContextsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTCONTEXTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.ListContexts][google.cloud.dialogflo
  w.v2beta1.Contexts.ListContexts].
  
  Attributes:
      parent:
          Required. The session to list all contexts from. Format:
          ``projects/<Project ID>/agent/sessions/<Session ID>`` or
          ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>``. If ``Environment
          ID`` is not specified, we assume default ‘draft’ environment.
          If ``User ID`` is not specified, we assume default ‘-’ user.
      page_size:
          Optional. The maximum number of items to return in a single
          page. By default 100 and at most 1000.
      page_token:
          Optional. The next_page_token value returned from a previous
          list request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListContextsRequest)
    },
)
_sym_db.RegisterMessage(ListContextsRequest)

ListContextsResponse = _reflection.GeneratedProtocolMessageType(
    "ListContextsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTCONTEXTSRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The response message for [Contexts.ListContexts][google.cloud.dialogfl
  ow.v2beta1.Contexts.ListContexts].
  
  Attributes:
      contexts:
          The list of contexts. There will be a maximum number of items
          returned based on the page_size field in the request.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListContextsResponse)
    },
)
_sym_db.RegisterMessage(ListContextsResponse)

GetContextRequest = _reflection.GeneratedProtocolMessageType(
    "GetContextRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETCONTEXTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.GetContext][google.cloud.dialogflow.
  v2beta1.Contexts.GetContext].
  
  Attributes:
      name:
          Required. The name of the context. Format: ``projects/<Project
          ID>/agent/sessions/<Session ID>/contexts/<Context ID>`` or
          ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>/contexts/<Context
          ID>``. If ``Environment ID`` is not specified, we assume
          default ‘draft’ environment. If ``User ID`` is not specified,
          we assume default ‘-’ user.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.GetContextRequest)
    },
)
_sym_db.RegisterMessage(GetContextRequest)

CreateContextRequest = _reflection.GeneratedProtocolMessageType(
    "CreateContextRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATECONTEXTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.CreateContext][google.cloud.dialogfl
  ow.v2beta1.Contexts.CreateContext].
  
  Attributes:
      parent:
          Required. The session to create a context for. Format:
          ``projects/<Project ID>/agent/sessions/<Session ID>`` or
          ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>``. If ``Environment
          ID`` is not specified, we assume default ‘draft’ environment.
          If ``User ID`` is not specified, we assume default ‘-’ user.
      context:
          Required. The context to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.CreateContextRequest)
    },
)
_sym_db.RegisterMessage(CreateContextRequest)

UpdateContextRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateContextRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATECONTEXTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.UpdateContext][google.cloud.dialogfl
  ow.v2beta1.Contexts.UpdateContext].
  
  Attributes:
      context:
          Required. The context to update.
      update_mask:
          Optional. The mask to control which fields get updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.UpdateContextRequest)
    },
)
_sym_db.RegisterMessage(UpdateContextRequest)

DeleteContextRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteContextRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETECONTEXTREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.DeleteContext][google.cloud.dialogfl
  ow.v2beta1.Contexts.DeleteContext].
  
  Attributes:
      name:
          Required. The name of the context to delete. Format:
          ``projects/<Project ID>/agent/sessions/<Session
          ID>/contexts/<Context ID>`` or ``projects/<Project
          ID>/agent/environments/<Environment ID>/users/<User
          ID>/sessions/<Session ID>/contexts/<Context ID>``. If
          ``Environment ID`` is not specified, we assume default ‘draft’
          environment. If ``User ID`` is not specified, we assume
          default ‘-’ user.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteContextRequest)
    },
)
_sym_db.RegisterMessage(DeleteContextRequest)

DeleteAllContextsRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteAllContextsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEALLCONTEXTSREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.context_pb2",
        "__doc__": """The request message for [Contexts.DeleteAllContexts][google.cloud.dial
  ogflow.v2beta1.Contexts.DeleteAllContexts].
  
  Attributes:
      parent:
          Required. The name of the session to delete all contexts from.
          Format: ``projects/<Project ID>/agent/sessions/<Session ID>``
          or ``projects/<Project ID>/agent/environments/<Environment
          ID>/users/<User ID>/sessions/<Session ID>``. If ``Environment
          ID`` is not specified we assume default ‘draft’ environment.
          If ``User ID`` is not specified, we assume default ‘-’ user.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteAllContextsRequest)
    },
)
_sym_db.RegisterMessage(DeleteAllContextsRequest)


DESCRIPTOR._options = None
_CONTEXT._options = None
_LISTCONTEXTSREQUEST.fields_by_name["parent"]._options = None
_GETCONTEXTREQUEST.fields_by_name["name"]._options = None
_CREATECONTEXTREQUEST.fields_by_name["parent"]._options = None
_CREATECONTEXTREQUEST.fields_by_name["context"]._options = None
_UPDATECONTEXTREQUEST.fields_by_name["context"]._options = None
_UPDATECONTEXTREQUEST.fields_by_name["update_mask"]._options = None
_DELETECONTEXTREQUEST.fields_by_name["name"]._options = None
_DELETEALLCONTEXTSREQUEST.fields_by_name["parent"]._options = None

_CONTEXTS = _descriptor.ServiceDescriptor(
    name="Contexts",
    full_name="google.cloud.dialogflow.v2beta1.Contexts",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=1454,
    serialized_end=4298,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListContexts",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.ListContexts",
            index=0,
            containing_service=None,
            input_type=_LISTCONTEXTSREQUEST,
            output_type=_LISTCONTEXTSRESPONSE,
            serialized_options=b"\202\323\344\223\002\254\002\0226/v2beta1/{parent=projects/*/agent/sessions/*}/contextsZO\022M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contextsZD\022B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contextsZ[\022Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetContext",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.GetContext",
            index=1,
            containing_service=None,
            input_type=_GETCONTEXTREQUEST,
            output_type=_CONTEXT,
            serialized_options=b"\202\323\344\223\002\254\002\0226/v2beta1/{name=projects/*/agent/sessions/*/contexts/*}ZO\022M/v2beta1/{name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}ZD\022B/v2beta1/{name=projects/*/locations/*/agent/sessions/*/contexts/*}Z[\022Y/v2beta1/{name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateContext",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.CreateContext",
            index=2,
            containing_service=None,
            input_type=_CREATECONTEXTREQUEST,
            output_type=_CONTEXT,
            serialized_options=b'\202\323\344\223\002\320\002"6/v2beta1/{parent=projects/*/agent/sessions/*}/contexts:\007contextZX"M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contexts:\007contextZM"B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contexts:\007contextZd"Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts:\007context\332A\016parent,context',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateContext",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.UpdateContext",
            index=3,
            containing_service=None,
            input_type=_UPDATECONTEXTREQUEST,
            output_type=_CONTEXT,
            serialized_options=b"\202\323\344\223\002\360\0022>/v2beta1/{context.name=projects/*/agent/sessions/*/contexts/*}:\007contextZ`2U/v2beta1/{context.name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}:\007contextZU2J/v2beta1/{context.name=projects/*/locations/*/agent/sessions/*/contexts/*}:\007contextZl2a/v2beta1/{context.name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}:\007context\332A\023context,update_mask\332A\007context",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteContext",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.DeleteContext",
            index=4,
            containing_service=None,
            input_type=_DELETECONTEXTREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\254\002*6/v2beta1/{name=projects/*/agent/sessions/*/contexts/*}ZO*M/v2beta1/{name=projects/*/agent/environments/*/users/*/sessions/*/contexts/*}ZD*B/v2beta1/{name=projects/*/locations/*/agent/sessions/*/contexts/*}Z[*Y/v2beta1/{name=projects/*/locations/*/agent/environments/*/users/*/sessions/*/contexts/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteAllContexts",
            full_name="google.cloud.dialogflow.v2beta1.Contexts.DeleteAllContexts",
            index=5,
            containing_service=None,
            input_type=_DELETEALLCONTEXTSREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\254\002*6/v2beta1/{parent=projects/*/agent/sessions/*}/contextsZO*M/v2beta1/{parent=projects/*/agent/environments/*/users/*/sessions/*}/contextsZD*B/v2beta1/{parent=projects/*/locations/*/agent/sessions/*}/contextsZ[*Y/v2beta1/{parent=projects/*/locations/*/agent/environments/*/users/*/sessions/*}/contexts\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_CONTEXTS)

DESCRIPTOR.services_by_name["Contexts"] = _CONTEXTS

# @@protoc_insertion_point(module_scope)
