# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/knowledge_base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/knowledge_base.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\022KnowledgeBaseProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n:google/cloud/dialogflow_v2beta1/proto/knowledge_base.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\xb1\x01\n\rKnowledgeBase\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x15\n\rlanguage_code\x18\x04 \x01(\t:`\xea\x41]\n\'dialogflow.googleapis.com/KnowledgeBase\x12\x32projects/{project}/knowledgeBases/{knowledge_base}"\x8d\x01\n\x19ListKnowledgeBasesRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\x12\'dialogflow.googleapis.com/KnowledgeBase\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01"~\n\x1aListKnowledgeBasesResponse\x12G\n\x0fknowledge_bases\x18\x01 \x03(\x0b\x32..google.cloud.dialogflow.v2beta1.KnowledgeBase\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"X\n\x17GetKnowledgeBaseRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'dialogflow.googleapis.com/KnowledgeBase"\xaa\x01\n\x1a\x43reateKnowledgeBaseRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\x12\'dialogflow.googleapis.com/KnowledgeBase\x12K\n\x0eknowledge_base\x18\x02 \x01(\x0b\x32..google.cloud.dialogflow.v2beta1.KnowledgeBaseB\x03\xe0\x41\x02"j\n\x1a\x44\x65leteKnowledgeBaseRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'dialogflow.googleapis.com/KnowledgeBase\x12\r\n\x05\x66orce\x18\x02 \x01(\x08"\x9f\x01\n\x1aUpdateKnowledgeBaseRequest\x12K\n\x0eknowledge_base\x18\x01 \x01(\x0b\x32..google.cloud.dialogflow.v2beta1.KnowledgeBaseB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01\x32\xe1\x0b\n\x0eKnowledgeBases\x12\x80\x02\n\x12ListKnowledgeBases\x12:.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest\x1a;.google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse"q\x82\xd3\xe4\x93\x02\x62\x12+/v2beta1/{parent=projects/*}/knowledgeBasesZ3\x12\x31/v2beta1/{parent=projects/*/agent}/knowledgeBases\xda\x41\x06parent\x12\xed\x01\n\x10GetKnowledgeBase\x12\x38.google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest\x1a..google.cloud.dialogflow.v2beta1.KnowledgeBase"o\x82\xd3\xe4\x93\x02\x62\x12+/v2beta1/{name=projects/*/knowledgeBases/*}Z3\x12\x31/v2beta1/{name=projects/*/agent/knowledgeBases/*}\xda\x41\x04name\x12\xa6\x02\n\x13\x43reateKnowledgeBase\x12;.google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest\x1a..google.cloud.dialogflow.v2beta1.KnowledgeBase"\xa1\x01\x82\xd3\xe4\x93\x02\x82\x01"+/v2beta1/{parent=projects/*}/knowledgeBases:\x0eknowledge_baseZC"1/v2beta1/{parent=projects/*/agent}/knowledgeBases:\x0eknowledge_base\xda\x41\x15parent,knowledge_base\x12\xdb\x01\n\x13\x44\x65leteKnowledgeBase\x12;.google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest\x1a\x16.google.protobuf.Empty"o\x82\xd3\xe4\x93\x02\x62*+/v2beta1/{name=projects/*/knowledgeBases/*}Z3*1/v2beta1/{name=projects/*/agent/knowledgeBases/*}\xda\x41\x04name\x12\xda\x02\n\x13UpdateKnowledgeBase\x12;.google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest\x1a..google.cloud.dialogflow.v2beta1.KnowledgeBase"\xd5\x01\x82\xd3\xe4\x93\x02\xa0\x01\x32:/v2beta1/{knowledge_base.name=projects/*/knowledgeBases/*}:\x0eknowledge_baseZR2@/v2beta1/{knowledge_base.name=projects/*/agent/knowledgeBases/*}:\x0eknowledge_base\xda\x41\x1aknowledge_base,update_mask\xda\x41\x0eknowledge_base\x1ax\xca\x41\x19\x64ialogflow.googleapis.com\xd2\x41Yhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflowB\xb0\x01\n#com.google.cloud.dialogflow.v2beta1B\x12KnowledgeBaseProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_KNOWLEDGEBASE = _descriptor.Descriptor(
    name="KnowledgeBase",
    full_name="google.cloud.dialogflow.v2beta1.KnowledgeBase",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBase.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBase.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBase.language_code",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A]\n'dialogflow.googleapis.com/KnowledgeBase\0222projects/{project}/knowledgeBases/{knowledge_base}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=274,
    serialized_end=451,
)


_LISTKNOWLEDGEBASESREQUEST = _descriptor.Descriptor(
    name="ListKnowledgeBasesRequest",
    full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\022'dialogflow.googleapis.com/KnowledgeBase",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=454,
    serialized_end=595,
)


_LISTKNOWLEDGEBASESRESPONSE = _descriptor.Descriptor(
    name="ListKnowledgeBasesResponse",
    full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="knowledge_bases",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse.knowledge_bases",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=597,
    serialized_end=723,
)


_GETKNOWLEDGEBASEREQUEST = _descriptor.Descriptor(
    name="GetKnowledgeBaseRequest",
    full_name="google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\n'dialogflow.googleapis.com/KnowledgeBase",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=725,
    serialized_end=813,
)


_CREATEKNOWLEDGEBASEREQUEST = _descriptor.Descriptor(
    name="CreateKnowledgeBaseRequest",
    full_name="google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\022'dialogflow.googleapis.com/KnowledgeBase",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="knowledge_base",
            full_name="google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest.knowledge_base",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=816,
    serialized_end=986,
)


_DELETEKNOWLEDGEBASEREQUEST = _descriptor.Descriptor(
    name="DeleteKnowledgeBaseRequest",
    full_name="google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\n'dialogflow.googleapis.com/KnowledgeBase",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest.force",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=988,
    serialized_end=1094,
)


_UPDATEKNOWLEDGEBASEREQUEST = _descriptor.Descriptor(
    name="UpdateKnowledgeBaseRequest",
    full_name="google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="knowledge_base",
            full_name="google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest.knowledge_base",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1097,
    serialized_end=1256,
)

_LISTKNOWLEDGEBASESRESPONSE.fields_by_name[
    "knowledge_bases"
].message_type = _KNOWLEDGEBASE
_CREATEKNOWLEDGEBASEREQUEST.fields_by_name[
    "knowledge_base"
].message_type = _KNOWLEDGEBASE
_UPDATEKNOWLEDGEBASEREQUEST.fields_by_name[
    "knowledge_base"
].message_type = _KNOWLEDGEBASE
_UPDATEKNOWLEDGEBASEREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
DESCRIPTOR.message_types_by_name["KnowledgeBase"] = _KNOWLEDGEBASE
DESCRIPTOR.message_types_by_name[
    "ListKnowledgeBasesRequest"
] = _LISTKNOWLEDGEBASESREQUEST
DESCRIPTOR.message_types_by_name[
    "ListKnowledgeBasesResponse"
] = _LISTKNOWLEDGEBASESRESPONSE
DESCRIPTOR.message_types_by_name["GetKnowledgeBaseRequest"] = _GETKNOWLEDGEBASEREQUEST
DESCRIPTOR.message_types_by_name[
    "CreateKnowledgeBaseRequest"
] = _CREATEKNOWLEDGEBASEREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteKnowledgeBaseRequest"
] = _DELETEKNOWLEDGEBASEREQUEST
DESCRIPTOR.message_types_by_name[
    "UpdateKnowledgeBaseRequest"
] = _UPDATEKNOWLEDGEBASEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KnowledgeBase = _reflection.GeneratedProtocolMessageType(
    "KnowledgeBase",
    (_message.Message,),
    {
        "DESCRIPTOR": _KNOWLEDGEBASE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """A knowledge base represents a collection of knowledge documents that
  you provide to Dialogflow. Your knowledge documents contain
  information that may be useful during conversations with end-users.
  Some Dialogflow features use knowledge bases when looking for a
  response to an end-user input.  For more information, see the
  `knowledge base guide
  <https://cloud.google.com/dialogflow/docs/how/knowledge-bases>`__.
  Note: The ``projects.agent.knowledgeBases`` resource is deprecated;
  only use ``projects.knowledgeBases``.
  
  Attributes:
      name:
          The knowledge base resource name. The name must be empty when
          creating a knowledge base. Format: ``projects/<Project
          ID>/knowledgeBases/<Knowledge Base ID>``.
      display_name:
          Required. The display name of the knowledge base. The name
          must be 1024 bytes or less; otherwise, the creation request
          fails.
      language_code:
          Language which represents the KnowledgeBase. When the
          KnowledgeBase is created/updated, this is populated for all
          non en-us languages. If not populated, the default language
          en-us applies.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.KnowledgeBase)
    },
)
_sym_db.RegisterMessage(KnowledgeBase)

ListKnowledgeBasesRequest = _reflection.GeneratedProtocolMessageType(
    "ListKnowledgeBasesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTKNOWLEDGEBASESREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.ListKnowledgeBases][google.cloud.d
  ialogflow.v2beta1.KnowledgeBases.ListKnowledgeBases].
  
  Attributes:
      parent:
          Required. The project to list of knowledge bases for. Format:
          ``projects/<Project ID>``.
      page_size:
          Optional. The maximum number of items to return in a single
          page. By default 10 and at most 100.
      page_token:
          Optional. The next_page_token value returned from a previous
          list request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListKnowledgeBasesRequest)
    },
)
_sym_db.RegisterMessage(ListKnowledgeBasesRequest)

ListKnowledgeBasesResponse = _reflection.GeneratedProtocolMessageType(
    "ListKnowledgeBasesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTKNOWLEDGEBASESRESPONSE,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Response message for [KnowledgeBases.ListKnowledgeBases][google.cloud.
  dialogflow.v2beta1.KnowledgeBases.ListKnowledgeBases].
  
  Attributes:
      knowledge_bases:
          The list of knowledge bases.
      next_page_token:
          Token to retrieve the next page of results, or empty if there
          are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.ListKnowledgeBasesResponse)
    },
)
_sym_db.RegisterMessage(ListKnowledgeBasesResponse)

GetKnowledgeBaseRequest = _reflection.GeneratedProtocolMessageType(
    "GetKnowledgeBaseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETKNOWLEDGEBASEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.GetKnowledgeBase][google.cloud.dia
  logflow.v2beta1.KnowledgeBases.GetKnowledgeBase].
  
  Attributes:
      name:
          Required. The name of the knowledge base to retrieve. Format
          ``projects/<Project ID>/knowledgeBases/<Knowledge Base ID>``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.GetKnowledgeBaseRequest)
    },
)
_sym_db.RegisterMessage(GetKnowledgeBaseRequest)

CreateKnowledgeBaseRequest = _reflection.GeneratedProtocolMessageType(
    "CreateKnowledgeBaseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEKNOWLEDGEBASEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.CreateKnowledgeBase][google.cloud.
  dialogflow.v2beta1.KnowledgeBases.CreateKnowledgeBase].
  
  Attributes:
      parent:
          Required. The project to create a knowledge base for. Format:
          ``projects/<Project ID>``.
      knowledge_base:
          Required. The knowledge base to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.CreateKnowledgeBaseRequest)
    },
)
_sym_db.RegisterMessage(CreateKnowledgeBaseRequest)

DeleteKnowledgeBaseRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteKnowledgeBaseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEKNOWLEDGEBASEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.DeleteKnowledgeBase][google.cloud.
  dialogflow.v2beta1.KnowledgeBases.DeleteKnowledgeBase].
  
  Attributes:
      name:
          Required. The name of the knowledge base to delete. Format:
          ``projects/<Project ID>/knowledgeBases/<Knowledge Base ID>``.
      force:
          Optional. Force deletes the knowledge base. When set to true,
          any documents in the knowledge base are also deleted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.DeleteKnowledgeBaseRequest)
    },
)
_sym_db.RegisterMessage(DeleteKnowledgeBaseRequest)

UpdateKnowledgeBaseRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateKnowledgeBaseRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEKNOWLEDGEBASEREQUEST,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.knowledge_base_pb2",
        "__doc__": """Request message for [KnowledgeBases.UpdateKnowledgeBase][google.cloud.
  dialogflow.v2beta1.KnowledgeBases.UpdateKnowledgeBase].
  
  Attributes:
      knowledge_base:
          Required. The knowledge base to update.
      update_mask:
          Optional. Not specified means ``update all``. Currently, only
          ``display_name`` can be updated, an InvalidArgument will be
          returned for attempting to update other fields.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.UpdateKnowledgeBaseRequest)
    },
)
_sym_db.RegisterMessage(UpdateKnowledgeBaseRequest)


DESCRIPTOR._options = None
_KNOWLEDGEBASE.fields_by_name["display_name"]._options = None
_KNOWLEDGEBASE._options = None
_LISTKNOWLEDGEBASESREQUEST.fields_by_name["parent"]._options = None
_LISTKNOWLEDGEBASESREQUEST.fields_by_name["page_size"]._options = None
_LISTKNOWLEDGEBASESREQUEST.fields_by_name["page_token"]._options = None
_GETKNOWLEDGEBASEREQUEST.fields_by_name["name"]._options = None
_CREATEKNOWLEDGEBASEREQUEST.fields_by_name["parent"]._options = None
_CREATEKNOWLEDGEBASEREQUEST.fields_by_name["knowledge_base"]._options = None
_DELETEKNOWLEDGEBASEREQUEST.fields_by_name["name"]._options = None
_UPDATEKNOWLEDGEBASEREQUEST.fields_by_name["knowledge_base"]._options = None
_UPDATEKNOWLEDGEBASEREQUEST.fields_by_name["update_mask"]._options = None

_KNOWLEDGEBASES = _descriptor.ServiceDescriptor(
    name="KnowledgeBases",
    full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031dialogflow.googleapis.com\322AYhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/dialogflow",
    create_key=_descriptor._internal_create_key,
    serialized_start=1259,
    serialized_end=2764,
    methods=[
        _descriptor.MethodDescriptor(
            name="ListKnowledgeBases",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.ListKnowledgeBases",
            index=0,
            containing_service=None,
            input_type=_LISTKNOWLEDGEBASESREQUEST,
            output_type=_LISTKNOWLEDGEBASESRESPONSE,
            serialized_options=b"\202\323\344\223\002b\022+/v2beta1/{parent=projects/*}/knowledgeBasesZ3\0221/v2beta1/{parent=projects/*/agent}/knowledgeBases\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetKnowledgeBase",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.GetKnowledgeBase",
            index=1,
            containing_service=None,
            input_type=_GETKNOWLEDGEBASEREQUEST,
            output_type=_KNOWLEDGEBASE,
            serialized_options=b"\202\323\344\223\002b\022+/v2beta1/{name=projects/*/knowledgeBases/*}Z3\0221/v2beta1/{name=projects/*/agent/knowledgeBases/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateKnowledgeBase",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.CreateKnowledgeBase",
            index=2,
            containing_service=None,
            input_type=_CREATEKNOWLEDGEBASEREQUEST,
            output_type=_KNOWLEDGEBASE,
            serialized_options=b'\202\323\344\223\002\202\001"+/v2beta1/{parent=projects/*}/knowledgeBases:\016knowledge_baseZC"1/v2beta1/{parent=projects/*/agent}/knowledgeBases:\016knowledge_base\332A\025parent,knowledge_base',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteKnowledgeBase",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.DeleteKnowledgeBase",
            index=3,
            containing_service=None,
            input_type=_DELETEKNOWLEDGEBASEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002b*+/v2beta1/{name=projects/*/knowledgeBases/*}Z3*1/v2beta1/{name=projects/*/agent/knowledgeBases/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateKnowledgeBase",
            full_name="google.cloud.dialogflow.v2beta1.KnowledgeBases.UpdateKnowledgeBase",
            index=4,
            containing_service=None,
            input_type=_UPDATEKNOWLEDGEBASEREQUEST,
            output_type=_KNOWLEDGEBASE,
            serialized_options=b"\202\323\344\223\002\240\0012:/v2beta1/{knowledge_base.name=projects/*/knowledgeBases/*}:\016knowledge_baseZR2@/v2beta1/{knowledge_base.name=projects/*/agent/knowledgeBases/*}:\016knowledge_base\332A\032knowledge_base,update_mask\332A\016knowledge_base",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_KNOWLEDGEBASES)

DESCRIPTOR.services_by_name["KnowledgeBases"] = _KNOWLEDGEBASES

# @@protoc_insertion_point(module_scope)
